@@ -16,22 +16,24 @@ class ChatMember(base.TelegramObject):
     status: base.String = fields.Field()
     custom_title: base.String = fields.Field()
     is_anonymous: base.Boolean = fields.Field()
-    until_date: datetime.datetime = fields.DateTimeField()
     can_be_edited: base.Boolean = fields.Field()
-    can_change_info: base.Boolean = fields.Field()
+    can_manage_chat: base.Boolean = fields.Field()
     can_post_messages: base.Boolean = fields.Field()
     can_edit_messages: base.Boolean = fields.Field()
     can_delete_messages: base.Boolean = fields.Field()
-    can_invite_users: base.Boolean = fields.Field()
+    can_manage_voice_chats: base.Boolean = fields.Field()
     can_restrict_members: base.Boolean = fields.Field()
-    can_pin_messages: base.Boolean = fields.Field()
     can_promote_members: base.Boolean = fields.Field()
+    can_change_info: base.Boolean = fields.Field()
+    can_invite_users: base.Boolean = fields.Field()
+    can_pin_messages: base.Boolean = fields.Field()
     is_member: base.Boolean = fields.Field()
     can_send_messages: base.Boolean = fields.Field()
     can_send_media_messages: base.Boolean = fields.Field()
     can_send_polls: base.Boolean = fields.Field()
     can_send_other_messages: base.Boolean = fields.Field()
     can_add_web_page_previews: base.Boolean = fields.Field()
+    until_date: datetime.datetime = fields.DateTimeField()
 
     def is_chat_creator(self) -> bool:
         return ChatMemberStatus.is_chat_creator(self.status)
